==> fusion-engine-0.1.0.tar.gz: fusion-engine-0.1.0/README.md <==
# Fusion Engine

![logo](https://user-images.githubusercontent.com/106883655/233103547-5693b2a3-22b9-4b68-ac2a-7220f16d48df.png)

Fusion is a game engine for creating graphical applications using the PySDL2 library and the programming language Python. It provides a simple coding interface for creating windows,
rendering graphics, and handling user input. It is and engine to create
games fast and easy!

## Development

Keep in mind that this project is in work, so if you want to see code,
then it is in dev branch but there is no 'full version' of this project!
We working hard to make first alpha version of it!

## Installation

To install our package, run this:

```bash
  pip install fusion-engine
```

If you want to run the example, then just run this command:

```bash
 git clone https://github.com/dimkauzh/fusion-engine
 cd fusion-engine
 python examples/example1.py
```

For different examples, you change the number to the number of the example file

## Community

Our community is just growing, so if you want to help us with the project,
it will be very helpful!
We have a discord server at this link (<https://discord.gg/Smg3CK4ZMc>)
Need to contact us? Just DM the Owner or CEO in discord and we will try to react as fast as possible

### Special thanks to these people❤️

- Zenthm (Contributing)
- XCarCedo (Contributing)
- FBS_Gamer (Discord server)

## Documentation

See at [The wiki of the project](https://github.com/dimkauzh/fusion-engine/wiki) (Still in work!)

## Coming features

We are working hard to implement very basic and complex stuff so our engine becomes more rigid. These features are worked on or will be worked on:

- Fysics system using PyMunk (Being worked on)
- Delta-Time (Finished!)
- Pip package and SetupTools (Being worked on)
- Ui (Being worked on)
- If you have more ideas, please tell us them in our discord group!

## About

Fusion Engine is currently (6/14/2023) build with Python and some Python libraries:

- PySDL2 is used for rendering and windowing
- PySDL2-DLL is used by PySDL2 for SDL2 binaries
- PyMunk is used for fysics simulation
- CX-Freeze is used for building executables (Temporary, it will change when SetupTools is setup)

### Future of this engine

This project began 1 may 2023. The original project began in C, but it's entirely rewritten in Python for it's big userbase and ease of use (productivity). This is actually also my EuroPython project.

Our cool ideas:

- Make a full GUI app (With something like Kyvi or TKinter) - Update: We are currenly working on it with tkinter

## 🚀 About Me

A 13 year old game developer with much passion about game development. So I made this project to grow my programming skills and just make a tool that I can use for myself or a tool for other people to help them develop games.

==> fusion-engine-0.2.0.tar.gz: fusion-engine-0.2.0/README.md <==
# Fusion Engine

![logo](https://user-images.githubusercontent.com/106883655/233103547-5693b2a3-22b9-4b68-ac2a-7220f16d48df.png)

Fusion is a game engine for creating graphical applications using the PySDL2 library and the programming language Python. It provides a simple coding interface for creating windows,
rendering graphics, and handling user input. It is and engine to create
games fast and easy!

## Development

Keep in mind that this project is in work, so if you want to see code,
then it is in dev branch but there is no 'full version' of this project!
We working hard to make first alpha version of it!

## Installation

To install our package, run this:

```bash
  pip install fusion-engine
```

Our PyPI package is at this [link](<https://pypi.org/project/fusion-engine/>)

If you want to run the example, then just run this command:

```bash
 git clone https://github.com/dimkauzh/fusion-engine
 cd fusion-engine
 python examples/example1.py
```

For different examples, you change the number to the number of the example file

## Community

Our community is just growing, so if you want to help us with the project,
it will be very helpful!
We have a discord server at this [link](https://discord.gg/Smg3CK4ZMc)
Need to contact us? Just DM the Owner or CEO in discord and we will try to react as fast as possible

### Special thanks to these people❤️

- Zenthm (Contributing)
- XCarCedo (Contributing)
- FBS_Gamer (Discord server)

## Documentation

See at [The wiki of the project](https://github.com/dimkauzh/fusion-engine/wiki) (Still in work!)

## Coming features

We are working hard to implement very basic and complex stuff so our engine becomes more rigid. These features are worked on or will be worked on:

- Physics system using PyMunk (Being worked on)
- Delta-Time (Finished!)
- Pip package and SetupTools (Being worked on)
- UI (Being worked on)
- If you have more ideas, please tell us them in our discord group!

## About

Fusion Engine is currently (6/14/2023) build with Python and some Python libraries:

- PySDL2 is used for rendering and windowing
- PySDL2-DLL is used by PySDL2 for SDL2 binaries
- PyMunk is used for fysics simulation
- CX-Freeze is used for building executables (Temporary, it will change when SetupTools is setup)

### Future of this engine

This project began May 1, 2023. The original project began in C, but it's entirely rewritten in Python for it's big userbase and ease of use (productivity). This is actually also my EuroPython project.

Our cool ideas:

- Make a full GUI app (With something like Kivy or Tkinter) - Update: We are currenly working on it with tkinter

## 🚀 About Me

A 13 year old game developer with much passion about game development. So I made this project to grow my programming skills and just make a tool that I can use for myself or a tool for other people to help them develop games.
